//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/From/GUIExamplesFactory.h
//! @brief     Defines class GUI::ExamplesFactory
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_FROM_GUIEXAMPLESFACTORY_H
#define BORNAGAIN_GUI_MODEL_FROM_GUIEXAMPLESFACTORY_H

#include <QString>

class SampleModel;
class MaterialModel;
class MultiLayerItem;

//! Class that generates GUI model from
namespace GUI::ExamplesFactory {

bool isValidExampleName(const QString& name);

//! Create a multilayer item of the built-in example with the given internal name.
//!
//! materialModel will be filled with the necessary materials from the sample.
MultiLayerItem* createMultiLayerItem(const QString& name, MaterialModel* materialModel);

//! The internal example name, e.g. for creation with createMultiLayerItem.
QStringList exampleNames();

//! Returns human readable name and description
std::tuple<QString, QString> exampleInfo(const QString& name);

} // namespace GUI::ExamplesFactory

#endif // BORNAGAIN_GUI_MODEL_FROM_GUIEXAMPLESFACTORY_H
